==> vue-link-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/link/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["disabled", "href", "icon", "type", "underline"]),
  emits: ["click"],
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("a", _vm._b({
    class: ["tiny-link", "tiny-link--additional", _vm.type ? "tiny-link--" + _vm.type : "", _vm.state.disabled && "is-disabled", _vm.underline && !_vm.state.disabled && "is-underline"],
    attrs: {
      "href": _vm.state.disabled ? null : _vm.href
    },
    on: {
      "click": _vm.handleClick
    }
  }, "a", _vm.a(_vm.$attrs, ["^on[A-Z]"]), false), [_vm.icon ? _c(_vm.icon, {
    tag: "component",
    staticClass: "tiny-svg-size tiny-link-svg",
    class: {
      "tiny-link-svg-only": !_vm.slots.default
    }
  }) : _vm._e(), _vm.slots.default ? _c("span", {
    staticClass: "tiny-link__inner"
  }, [_vm._t("default")], 2) : _vm._e(), _vm.slots.icon ? _vm._t("icon") : _vm._e()], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-link-2.22.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/link/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["disabled", "href", "icon", "type", "underline", "value"]),
  emits: ["click"],
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("a", _vm._b({
    class: ["tiny-link", "tiny-link--additional", _vm.type ? "tiny-link--" + _vm.type : "", _vm.state.disabled && "is-disabled", _vm.underline && !_vm.state.disabled && "is-underline"],
    attrs: {
      "href": _vm.state.disabled ? null : _vm.state.href,
      "rel": "noopener noreferrer"
    },
    on: {
      "click": _vm.handleClick
    }
  }, "a", _vm.a(_vm.$attrs, ["^on[A-Z]"]), false), [_vm.icon ? _c(_vm.icon, {
    tag: "component",
    staticClass: "tiny-svg-size tiny-link-svg",
    class: {
      "tiny-link-svg-only": !(_vm.slots.default || _vm.value)
    }
  }) : _vm._e(), _vm.value ? _c("span", {
    staticClass: "tiny-link__inner"
  }, [_vm._v(" " + _vm._s(_vm.value) + " ")]) : _vm.slots.default ? _c("span", {
    staticClass: "tiny-link__inner"
  }, [_vm._t("default")], 2) : _vm._e(), _vm.slots.icon ? _vm._t("icon") : _vm._e()], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
